@@ -6,11 +6,13 @@
 """
 Trajectory Class tests.
 """
-import matplotlib.pyplot as plt
+
+
 import numpy as np
 from astropy import units as u
 from astropy.coordinates import CartesianDifferential, CartesianRepresentation, SkyCoord
 from astropy.time import Time, TimeDelta
+from matplotlib import pyplot as plt
 from sgp4.api import Satrec
 
 from satmad.coordinates.frames import TEME
@@ -18,21 +20,24 @@ from satmad.coordinates.trajectory import Trajectory
 from satmad.propagation.tle import TLE
 
 
-def propagation_engine(line1, line2, init_time, generate_plots=False):
-    """Tests the interpolation accuracy for a given TLE."""
-
-    # Init satellite object from the TLE
-    sat = Satrec.twoline2rv(line1, line2)
-
+def generate_timelist(init_time, duration, steps):
+    """generates the time lists for propagation."""
     # ****** Generate the discrete time instants through the propagation duration ******
-    duration = TimeDelta(3.0, format="jd")
-    steps = 4000  # number of steps within the propagation duration
     dt = duration / steps
 
     # Generate time list
     dt_list = dt * np.arange(0, steps, 1)
     time_list = init_time + dt_list
 
+    return dt, time_list
+
+
+def propagation_engine(line1, line2, time_list):
+    """Tests the interpolation accuracy for a given TLE."""
+
+    # Init satellite object from the TLE
+    sat = Satrec.twoline2rv(line1, line2)
+
     # ****** Generate the pos, vel vectors for each time instant ******
 
     # Run the propagation and init pos and vel vectors in TEME
@@ -56,6 +61,11 @@ def propagation_engine(line1, line2, init_time, generate_plots=False):
     # Init trajectory in Trajectory object
     trajectory = Trajectory(traj_astropy)
 
+    return {"traj": trajectory, "sat": sat}
+
+
+def check_errors(init_time, dt, sat, trajectory, generate_plots=False):
+    """Checks the errors for the given trajectory."""
     # **** Check the results ****
     step_offset = 0
     test_stepsize = 1.0 * u.s
@@ -119,6 +129,34 @@ def propagation_engine(line1, line2, init_time, generate_plots=False):
     return max_err, max_nominal_err
 
 
+def test_trajectory_export():
+    """Tests the interpolation accuracy for ISS."""
+
+    # Init TLE
+    line1 = "1 25544U 98067A   19343.69339541  .00001764  00000-0  38792-4 0  9991"
+    line2 = "2 25544  51.6439 211.2001 0007417  17.6667  85.6398 15.50103472202482"
+
+    # test init time
+    init_time = Time(2458826.3, format="jd", scale="utc")
+    init_time.format = "isot"
+
+    duration = TimeDelta(3.0, format="jd")
+    steps = 4000  # number of steps within the propagation duration
+
+    dt, time_list = generate_timelist(init_time, duration, steps)
+    prop_output = propagation_engine(line1, line2, time_list)
+
+    ts = prop_output["traj"].to_timeseries()
+
+    pvt = prop_output["traj"].coord_list[10]
+
+    print(ts)
+    # print(ts["time", "v_X"])
+
+    assert (ts.time[10] - pvt.obstime) < 17 * u.us
+    assert (ts[10]["r_X"] - pvt.cartesian.x) < 1 * u.um
+
+
 def test_interpolation_err_iss():
     """Tests the interpolation accuracy for ISS."""
 
@@ -129,7 +167,14 @@ def test_interpolation_err_iss():
     # test init time
     init_time = Time(2458826.3, format="jd", scale="utc")
 
-    max_begin_err, max_nominal_err = propagation_engine(line1, line2, init_time, False)
+    duration = TimeDelta(3.0, format="jd")
+    steps = 4000  # number of steps within the propagation duration
+
+    dt, time_list = generate_timelist(init_time, duration, steps)
+    prop_output = propagation_engine(line1, line2, time_list)
+    max_begin_err, max_nominal_err = check_errors(
+        init_time, dt, prop_output["sat"], prop_output["traj"], False
+    )
 
     assert max_begin_err < 16 * u.mm
     assert max_nominal_err < 0.08 * u.mm
@@ -145,7 +190,14 @@ def test_interpolation_err_geo():
     # test init time
     init_time = Time("2020:162:09:00:00", format="yday", scale="utc")
 
-    max_err, max_nominal_err = propagation_engine(line1, line2, init_time, False)
+    duration = TimeDelta(3.0, format="jd")
+    steps = 4000  # number of steps within the propagation duration
+
+    dt, time_list = generate_timelist(init_time, duration, steps)
+    prop_output = propagation_engine(line1, line2, time_list)
+    max_err, max_nominal_err = check_errors(
+        init_time, dt, prop_output["sat"], prop_output["traj"], False
+    )
 
     assert max_err < 0.0005 * u.mm
     assert max_nominal_err < 0.0003 * u.mm
@@ -171,8 +223,13 @@ def test_interpolation_err_heo():
 
     # print(tle)
 
-    max_err, max_nominal_err = propagation_engine(
-        heo_line1, heo_line2, init_time, False
+    duration = TimeDelta(3.0, format="jd")
+    steps = 4000  # number of steps within the propagation duration
+
+    dt, time_list = generate_timelist(init_time, duration, steps)
+    prop_output = propagation_engine(heo_line1, heo_line2, time_list)
+    max_err, max_nominal_err = check_errors(
+        init_time, dt, prop_output["sat"], prop_output["traj"], False
     )
 
     assert max_err < 0.040 * u.mm
