@@ -9,6 +9,36 @@ Interpolators used throughout the project.
 """
 from scipy import interpolate as ip
 
+from satmad.utils.timeinterval import TimeInterval
+
+
+class DiscreteTimeData:
+    def __init__(self, time_list, value_list):
+        # Check whether time_list and value_list size are equal
+        if len(time_list) != len(value_list):
+            raise ValueError(
+                f"Time list and value list are of different sizes. "
+                f"({len(time_list)} vs. ({len(value_list)}))"
+            )
+
+        # Check whether time_list and value_list size are equal
+        if len(time_list) != len(value_list):
+            raise ValueError(
+                f"Time list and value list are of different sizes. "
+                f"({len(time_list)} vs. ({len(value_list)}))"
+            )
+
+        self.data_interval = TimeInterval(time_list[0], time_list[-1])
+
+        # Convert time to "days since epoch"
+        t_float_list = (time_list - time_list[0]).jd
+
+        # Init interpolators (for splines, root finding possible for 3rd degree
+        # (cubics) only)
+        self._interpolator = ip.CubicSpline(t_float_list, value_list)
+
+        self._deriv_interpolator = self._interpolator.derivative()
+
 
 class CartInterpolator3D:
     """
